==> igniteui-react-charts-18.7.0-beta.2.tgz: package/esm2015/lib/SlowStochasticOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { SlowStochasticOscillatorIndicatorStrategy } from "./SlowStochasticOscillatorIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
import { Brush } from "igniteui-react-core";
/**
 * @hidden
 */
export let SlowStochasticOscillatorIndicator = /*@__PURE__*/ (() => {
    class SlowStochasticOscillatorIndicator extends StrategyBasedIndicator {
        bi() {
            return new SlowStochasticOscillatorIndicator();
        }
        constructor() {
            super();
            this.trendLineBrush = ((() => {
                let $ret = new Brush();
                $ret.fill = "#565656";
                return $ret;
            })());
            this.trendLineType = 10;
            this.trendLinePeriod = 3;
        }
        get_abm() {
            return new SlowStochasticOscillatorIndicatorStrategy();
        }
        get abm() {
            return this.get_abm();
        }
        get_abz() {
            return SlowStochasticOscillatorIndicator.$;
        }
        get abz() {
            return this.get_abz();
        }
        get ab7() {
            return typeGetValue(this.c(SlowStochasticOscillatorIndicator.ab8));
        }
        set ab7(a) {
            this.h(SlowStochasticOscillatorIndicator.ab8, a);
        }
        abs() {
            return this.ab7;
        }
        ab1(a) {
            this.ab7 = a;
        }
    }
    SlowStochasticOscillatorIndicator.$t = /*@__PURE__*/ markType(SlowStochasticOscillatorIndicator, 'SlowStochasticOscillatorIndicator', StrategyBasedIndicator.$);
    SlowStochasticOscillatorIndicator.ab8 = /*@__PURE__*/ StrategyBasedIndicator.ab4(14, SlowStochasticOscillatorIndicator.$);
    return SlowStochasticOscillatorIndicator;
})();

==> igniteui-react-charts-18.7.5-beta.2.tgz: package/esm2015/lib/SlowStochasticOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { SlowStochasticOscillatorIndicatorStrategy } from "./SlowStochasticOscillatorIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
import { Brush } from "igniteui-react-core";
/**
 * @hidden
 */
export let SlowStochasticOscillatorIndicator = /*@__PURE__*/ (() => {
    class SlowStochasticOscillatorIndicator extends StrategyBasedIndicator {
        bj() {
            return new SlowStochasticOscillatorIndicator();
        }
        constructor() {
            super();
            this.trendLineBrush = ((() => {
                let $ret = new Brush();
                $ret.fill = "#565656";
                return $ret;
            })());
            this.trendLineType = 10;
            this.trendLinePeriod = 3;
        }
        get_abv() {
            return new SlowStochasticOscillatorIndicatorStrategy();
        }
        get abv() {
            return this.get_abv();
        }
        get_ab8() {
            return SlowStochasticOscillatorIndicator.$;
        }
        get ab8() {
            return this.get_ab8();
        }
        get acg() {
            return typeGetValue(this.c(SlowStochasticOscillatorIndicator.ach));
        }
        set acg(a) {
            this.h(SlowStochasticOscillatorIndicator.ach, a);
        }
        ab1() {
            return this.acg;
        }
        aca(a) {
            this.acg = a;
        }
    }
    SlowStochasticOscillatorIndicator.$t = /*@__PURE__*/ markType(SlowStochasticOscillatorIndicator, 'SlowStochasticOscillatorIndicator', StrategyBasedIndicator.$);
    SlowStochasticOscillatorIndicator.ach = /*@__PURE__*/ StrategyBasedIndicator.acd(14, SlowStochasticOscillatorIndicator.$);
    return SlowStochasticOscillatorIndicator;
})();
